Feedforward Closedloop Learning: feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank Class Reference

Feedforward Closedloop Learning

Public Member Functions | Properties | List of all members
feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank Class Reference
Inheritance diagram for feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank:
[legend]
Collaboration diagram for feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank:
[legend]

## Public Member Functions
def | __init__ (self, "int" num_of_inputs, "int *" num_of_neurons_per_layer_array, "int" num_filtersInput, "double" minT, "double" maxT)
"void" | doStep (self, *args)
"double" | getFilterOutput (self, "int" inputIdx, "int" filterIdx)
"int" | getNFiltersPerInput (self)
Public Member Functions inherited from feedforward_closedloop_learning.FeedforwardClosedloopLearning
def | __init__ (self, "int" num_of_inputs, "int *" num_of_neurons_per_layer_array)
"double" | getOutput (self, "int" index)
"void" | setLearningRate (self, "double" learningRate)
"void" | setLearningRateDiscountFactor (self, "double" _learningRateDiscountFactor)
"void" | setDecay (self, "double" decay)
"void" | setMomentum (self, "double" momentum)
"void" | setActivationFunction (self, "Neuron::ActivationFunction" _activationFunction)
"void" | initWeights (self, *args)
"void" | seedRandom (self, "int" s)
"void" | setBias (self, "double" _bias)
"int" | getNumLayers (self)
"Layer *" | getLayer (self, "int" i)
"Layer *" | getOutputLayer (self)
"int" | getNumInputs (self)
"Layer **" | getLayers (self)
"bool" | saveModel (self, "char const *" name)
"bool" | loadModel (self, "char const *" name)

## Properties
| thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
Properties inherited from feedforward_closedloop_learning.FeedforwardClosedloopLearning
| thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

## Detailed Description

    Proxy of C++ FeedforwardClosedloopLearningWithFilterbank class.

## Constructor & Destructor Documentation

## ◆ __init__()

def feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank.__init__ | ( |  | self,
|  | "int" | num_of_inputs,
|  | "int *" | num_of_neurons_per_layer_array,
|  | "int" | num_filtersInput,
|  | "double" | minT,
|  | "double" | maxT
| ) |  |

    __init__(FeedforwardClosedloopLearningWithFilterbank self, int num_of_inputs, int * num_of_neurons_per_layer_array, int num_filtersInput, double minT, double maxT) -> FeedforwardClosedloopLearningWithFilterbank

    Parameters
    ----------
    num_of_inputs: int
    num_of_neurons_per_layer_array: int *
    num_filtersInput: int
    minT: double
    maxT: double

## Member Function Documentation

## ◆ doStep()

"void" feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank.doStep | ( |  | self,
|  | * | args
| ) |  |

    doStep(FeedforwardClosedloopLearningWithFilterbank self, double * input, double * error)

    Parameters
    ----------
    input: double *
    error: double *

    doStep(FeedforwardClosedloopLearningWithFilterbank self, double * input, double * error)

    Parameters
    ----------
    input: double *
    error: double *

Reimplemented from feedforward_closedloop_learning.FeedforwardClosedloopLearning.

## ◆ getFilterOutput()

"double" feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank.getFilterOutput | ( |  | self,
|  | "int" | inputIdx,
|  | "int" | filterIdx
| ) |  |

    getFilterOutput(FeedforwardClosedloopLearningWithFilterbank self, int inputIdx, int filterIdx) -> double

    Parameters
    ----------
    inputIdx: int
    filterIdx: int

## ◆ getNFiltersPerInput()

"int" feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank.getNFiltersPerInput | ( |  | self | ) |

    getNFiltersPerInput(FeedforwardClosedloopLearningWithFilterbank self) -> int

The documentation for this class was generated from the following file:

- feedforward_closedloop_learning.py